load Golub.mat

mdata = datatrain;
[d n] = size(mdata);
 

  %  Create generic icolor & markerstr for Classes
  %
  icolor = [] ;
  markerstr = [] ;
  ALLFlag = zeros(1,n) ;
  AMLFlag = zeros(1,n) ; 
  for ialpha = 1:n; 
    if strcmp(trainlabel{ialpha},'ALL') ;
      icolor = [icolor; [0 0 1]] ;
      markerstr = strvcat(markerstr,'o') ;
      ALLFlag(ialpha) = 1 ;
    elseif strcmp(trainlabel{ialpha},'AML') ;
      icolor = [icolor; [1 0 0]] ;
      markerstr = strvcat(markerstr,'x') ;
      AMLFlag(ialpha) = 1 ; 
    end ; 
  end ;

  ALLFlag = logical(ALLFlag) ;
  AMLFlag = logical(AMLFlag) ; 


  %  Set up generic legend
  %
  legendcellstr = {{'ALL' 'AML' }} ;
  mlegendcolor = [[0 0 1]; [1 0 0]] ;
 
  
  figure(1);clf;
  image(mdata);
  title('Processed gene expressions (Golub)');
  xlabel('subject index: 1-27 =  ALL, 28-37 = AML');
  ylabel('genes');
  colorbar;
  print('-dpdf','Golub_matrix');
  
  figure(2);clf;
  mdir = [eye(3); zeros(d-3,3)];
  paramstruct = struct('npcadiradd', 0, 'icolor',icolor, ...
      'markerstr',markerstr,'legendcellstr',legendcellstr, ...
      'mlegendcolor',mlegendcolor, ...
      'labelcellstr',{{'X_1';'X_2';'X_3'}});
  scatplotSM(mdata, mdir, paramstruct)
  
  print('-dpdf','Golub_scatplot1');
  
  figure(3);clf;
  paramstruct = struct('npcadiradd', 3, 'icolor',icolor, ...
      'markerstr',markerstr,'legendcellstr',legendcellstr, ...
      'mlegendcolor',mlegendcolor);
  scatplotSM(mdata, [], paramstruct)
  print('-dpdf','Golub_scatplot2');
  
  
%% LDA

[ldadir, cutpoint] = lda(mdata,ALLFlag,0.1,0);
  figure(3);clf;
  paramstruct = struct('npcadiradd', 2, 'icolor',icolor, ...
      'markerstr',markerstr,'legendcellstr',legendcellstr, ...
      'mlegendcolor',mlegendcolor, ...
      'labelcellstr',{{'Discriminant Dir.'}});
  scatplotSM(mdata, ldadir, paramstruct)
  print('-dpdf','Golub_scatplot3');
   

  %% Confidence interval.
  % Take the first two genes:
  meand = mean(mdata(:,ALLFlag),2) - mean(mdata(:,AMLFlag),2);
  [~,sind]=sort(meand);
  
  gene12ALL = mdata([1, 1674],ALLFlag);
  gene12AML = mdata([1, 1674],AMLFlag);
  figure(4);clf;
  scatter(gene12ALL(1,:),gene12ALL(2,:),'or');
  hold on;
  scatter(gene12AML(1,:),gene12AML(2,:),'ob');
  title('Golub data, ALL (red) and AML(blue)');
  xlabel('gene #1')
  ylabel('gene #1674')
  xbar1 = mean(gene12ALL,2);
  xbar2 = mean(gene12AML,2);
  S1 = cov(gene12ALL');
  S2 = cov(gene12AML');
  
  % compute ellipse 1
  p = 2;
  n = sum(ALLFlag);
  theta = linspace(0,2*pi,202);
  [U L]=svd(S1);
  l = sqrt(diag(L));
  F = (n-1)/n*p/(n-p)*finv(0.95,p,n-p);
  ell1 = U*[l(1)*cos(theta); l(2)*sin(theta)]*sqrt(F)+ repmat(xbar1,1,202);
  plot(ell1(1,:),ell1(2,:),'r');
  F = (n-1)/n*p/(n-p)*finv(0.99,p,n-p);
  ell199 = U*[l(1)*cos(theta); l(2)*sin(theta)]*sqrt(F)+ repmat(xbar1,1,202);
  plot(ell199(1,:),ell199(2,:),':r');
  
  % compute ellipse 2
  p = 2;
  n = sum(AMLFlag);
  theta = linspace(0,2*pi,202);
  [U L]=svd(S2);
  l = sqrt(diag(L));
  F = (n-1)/n*p/(n-p)*finv(0.95,p,n-p);
  ell2 = U*[l(1)*cos(theta); l(2)*sin(theta)]*sqrt(F)+ repmat(xbar2,1,202);
  plot(ell2(1,:),ell2(2,:),'b');
  F = (n-1)/n*p/(n-p)*finv(0.99,p,n-p);
  ell299 = U*[l(1)*cos(theta); l(2)*sin(theta)]*sqrt(F)+ repmat(xbar2,1,202);
  plot(ell299(1,:),ell299(2,:),':b');
  
  print('-dpdf','Golub_EllipticalCR');
  
  % Now compute simultaneous interval box
  figure(4);clf;
  scatter(gene12ALL(1,:),gene12ALL(2,:),'or');
  hold on;
  scatter(gene12AML(1,:),gene12AML(2,:),'ob');
  title('Golub data, ALL (red) and AML(blue)');
  xlabel('gene #1')
  ylabel('gene #1674')
  plot(ell1(1,:),ell1(2,:),'r');
  plot(ell2(1,:),ell2(2,:),'b');

  p = 2;
  n = sum(ALLFlag);
  w = sqrt(p/(n-p)*finv(0.95,p,n-p)*S1(1,1));
  low1 = xbar1(1) - w;
  h = sqrt(p/(n-p)*finv(0.95,p,n-p)*S1(2,2));
  low2 = xbar1(2) - h;
  rectangle('Position',[low1,low2,2*w,2*h])
  p = 2;
  n = sum(AMLFlag);
  w = sqrt(p/(n-p)*finv(0.95,p,n-p)*S2(1,1));
  low1 = xbar2(1) - w;
  h = sqrt(p/(n-p)*finv(0.95,p,n-p)*S2(2,2));
  low2 = xbar2(2) - h;
  rectangle('Position',[low1,low2,2*w,2*h])
  print('-dpdf','Golub_SimulCR');
  
  
  
